| Title: | Model Wrappers for Poisson Regression |
|---|---|
| Description: | Bindings for Poisson regression models for use with the 'parsnip' package. Models include simple generalized linear models, Bayesian models, and zero-inflated Poisson models (Zeileis, Kleiber, and Jackman (2008) <doi:10.18637/jss.v027.i08>). |
| Authors: | Max Kuhn [aut] (ORCID: <https://orcid.org/0000-0003-2402-136X>), Hannah Frick [aut, cre] (ORCID: <https://orcid.org/0000-0002-6049-5258>), Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>) |
| Maintainer: | Hannah Frick <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.2.9000 |
| Built: | 2026-05-14 15:33:29 UTC |
| Source: | https://github.com/tidymodels/poissonreg |
Alcohol, Cigarette, and Marijuana Use for High School Seniors
Data are from Table 7.3 of Agresti (2007). The first three columns make up data from a 3-way contingency table.
seniors |
a tibble |
Agresti, A (2007). An Introduction to Categorical Data Analysis.
data(seniors) str(seniors)data(seniors) str(seniors)
Turn zero-inflated model results into a tidy tibble
## S3 method for class 'zeroinfl' tidy(x, type = "count", ...) ## S3 method for class 'hurdle' tidy(x, type = "count", ...)## S3 method for class 'zeroinfl' tidy(x, type = "count", ...) ## S3 method for class 'hurdle' tidy(x, type = "count", ...)
x |
A |
type |
A character string for which model coefficients to return: "all", "count", or "zero". |
... |
Not currently used. |
A tibble